==> myfaces-core-assembly-2.0.25-src.tar.gz: myfaces-core-module-2.0.25/impl/src/main/java/org/apache/myfaces/config/element/Application.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.config.element;

import java.io.Serializable;
import java.util.List;

/**
 * 
 * @author Leonardo Uribe
 * @since 2.0.3
 */
public abstract class Application implements Serializable
{

    public abstract List<String> getActionListener();

    public abstract List<String> getDefaultRenderkitId();
    
    public abstract List<String> getDefaultValidatorIds();
    
    public abstract List<String> getMessageBundle();

    public abstract List<String> getNavigationHandler();
    
    public abstract List<String> getPartialTraversal ();
    
    public abstract List<String> getResourceHandler();
    
    public abstract List<SystemEventListener> getSystemEventListeners ();
    
    public abstract List<String> getViewHandler();

    public abstract List<String> getStateManager();

    public abstract List<String> getPropertyResolver();

    public abstract List<String> getVariableResolver();

    public abstract List<LocaleConfig> getLocaleConfig();

    public abstract List<String> getElResolver();

    public abstract List<ResourceBundle> getResourceBundle();

    public abstract boolean isDefaultValidatorsPresent();

}

==> myfaces-core-assembly-2.3.9-src.tar.gz: myfaces-core-module-2.3.9/impl/src/main/java/org/apache/myfaces/config/element/Application.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.config.element;

import java.io.Serializable;
import java.util.List;

/**
 * 
 * @author Leonardo Uribe
 * @since 2.0.3
 */
public abstract class Application implements Serializable
{

    public abstract List<String> getActionListener();

    public abstract List<String> getDefaultRenderkitId();
    
    public abstract List<String> getDefaultValidatorIds();
    
    public abstract List<String> getMessageBundle();

    public abstract List<String> getNavigationHandler();
    
    public abstract List<String> getPartialTraversal ();
    
    public abstract List<String> getResourceHandler();
    
    public abstract List<SystemEventListener> getSystemEventListeners ();
    
    public abstract List<String> getViewHandler();

    public abstract List<String> getStateManager();

    public abstract List<String> getPropertyResolver();

    public abstract List<String> getVariableResolver();

    public abstract List<LocaleConfig> getLocaleConfig();

    public abstract List<String> getElResolver();

    public abstract List<ResourceBundle> getResourceBundle();

    public abstract boolean isDefaultValidatorsPresent();

    public abstract List<ContractMapping> getResourceLibraryContractMappings();
    
    public abstract List<String> getSearchKeywordResolver();
    
    public abstract List<String> getSearchExpressionHandler();
}
